@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
- * Copyright (C) 2006-2007 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2006-2007 Thomas Zander <zander@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef KOSHAPECONFIGWIDGETBASE_H
@@ -27,7 +14,7 @@
 class KoShape;
 class KUndo2Command;
 class KoUnit;
-class KoCanvasResourceManager;
+class KoCanvasResourceProvider;
 
 /**
  * Base widget for shape-configuration panels.
@@ -74,7 +61,7 @@ public:
     virtual void setUnit(const KoUnit &unit);
 
     /// called to set the canvas resource manager of the canvas the user used to insert the new shape.
-    void setResourceManager(KoCanvasResourceManager *rm);
+    void setResourceManager(KoCanvasResourceProvider *rm);
 
     /// Return true if the shape config panel should be shown after the shape is created
     virtual bool showOnShapeCreate();
@@ -93,7 +80,7 @@ Q_SIGNALS:
     void accept();
 
 protected:
-    KoCanvasResourceManager *m_resourceManager; ///< the resource provider with data for this canvas
+    KoCanvasResourceProvider *m_resourceManager; ///< the resource provider with data for this canvas
 };
 
 #endif
