@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
- * Copyright (C) 2012 Boudewijn Rempt <boud@kogmbh.com>
+ * SPDX-FileCopyrightText: 2012 Boudewijn Rempt <boud@kogmbh.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 #include "KisSketchView.h"
 
@@ -71,7 +58,7 @@ public:
 
     KisSketchView* q;
 
-    KActionCollection *actionCollection;
+    KisKActionCollection *actionCollection;
 
     QPointer<KisDocument> doc;
     QPointer<KisViewManager> viewManager;
@@ -107,7 +94,7 @@ KisSketchView::KisSketchView(QQuickItem* parent)
     setAcceptedMouseButtons(Qt::LeftButton | Qt::MiddleButton | Qt::RightButton);
     setAcceptHoverEvents(true);
 
-    d->actionCollection = new KActionCollection(this, "krita");
+    d->actionCollection = new KisKActionCollection(this, "krita");
     d->viewManager = 0; //new KisViewManager(qApp->activeWindow(), d->actionCollection);
 
     // QT5TODO
@@ -405,7 +392,7 @@ bool KisSketchView::event( QEvent* event )
 
 //                syncObject->mirrorHorizontal = provider->mirrorHorizontal();
 //                syncObject->mirrorVertical = provider->mirrorVertical();
-//                //syncObject->mirrorAxesCenter = provider->resourceManager()->resource(KisCanvasResourceProvider::MirrorAxesCenter).toPointF();
+//                //syncObject->mirrorAxesCenter = provider->resourceManager()->resource(KoCanvasResource::MirrorAxesCenter).toPointF();
 
 //                KisToolFreehand* tool = qobject_cast<KisToolFreehand*>(KoToolManager::instance()->toolById(d->view->canvasBase(), syncObject->activeToolId));
 //                if(tool) {
@@ -442,7 +429,7 @@ bool KisSketchView::event( QEvent* event )
 
 //                provider->setMirrorHorizontal(syncObject->mirrorHorizontal);
 //                provider->setMirrorVertical(syncObject->mirrorVertical);
-//                //provider->resourceManager()->setResource(KisCanvasResourceProvider::MirrorAxesCenter, syncObject->mirrorAxesCenter);
+//                //provider->resourceManager()->setResource(KoCanvasResource::MirrorAxesCenter, syncObject->mirrorAxesCenter);
 
 //                provider->setPaintOpPreset(syncObject->paintOp);
 //                qApp->processEvents();
