@@ -1,20 +1,7 @@
 /*
- * Copyright (C) 2016 Boudewijn Rempt <boud@valdyas.org>
+ * SPDX-FileCopyrightText: 2016 Boudewijn Rempt <boud@valdyas.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "KisReferenceImagesDecoration.h"
@@ -34,7 +21,7 @@ struct KisReferenceImagesDecoration::Private {
 
         QRectF bounds() const
         {
-            return QRectF(position, image.size());
+            return QRectF(position, image.size() / image.devicePixelRatio());
         }
     };
 
@@ -67,6 +54,7 @@ private:
         KisCoordinatesConverter *viewConverter = q->view()->viewConverter();
         QTransform transform = viewConverter->imageToWidgetTransform();
 
+        qreal devicePixelRatioF = q->view()->devicePixelRatioF();
         if (buffer.image.isNull() || !buffer.bounds().contains(widgetRect)) {
             const QRectF boundingImageRect = layer->boundingImageRect();
             const QRectF boundingWidgetRect = q->view()->viewConverter()->imageToWidget(boundingImageRect);
@@ -75,10 +63,13 @@ private:
             if (widgetRect.isNull()) return;
 
             buffer.position = widgetRect.topLeft();
-            buffer.image = QImage(widgetRect.size().toSize(), QImage::Format_ARGB32);
-            buffer.image.fill(Qt::transparent);
+            // to ensure that buffer is big enough for all the pixels on high dpi displays
+            // BUG 411118
+            buffer.image = QImage((widgetRect.size()*devicePixelRatioF).toSize(), QImage::Format_ARGB32);
+            buffer.image.setDevicePixelRatio(devicePixelRatioF);
 
             imageRect = q->view()->viewConverter()->widgetToImage(widgetRect);
+
         }
 
         QPainter gc(&buffer.image);
@@ -91,20 +82,24 @@ private:
         gc.fillRect(imageRect, Qt::transparent);
         gc.restore();
 
-        gc.setClipRect(imageRect);
+        // to ensure that clipping rect is also big enough for all the pixels
+        // BUG 411118
+        gc.setClipRect(QRectF(imageRect.topLeft(), imageRect.size()*devicePixelRatioF));
         layer->paintReferences(gc);
     }
 };
 
-KisReferenceImagesDecoration::KisReferenceImagesDecoration(QPointer<KisView> parent, KisDocument *document)
+KisReferenceImagesDecoration::KisReferenceImagesDecoration(QPointer<KisView> parent, KisDocument *document, bool viewReady)
     : KisCanvasDecoration("referenceImagesDecoration", parent)
     , d(new Private(this))
 {
     connect(document->image().data(), SIGNAL(sigNodeAddedAsync(KisNodeSP)), this, SLOT(slotNodeAdded(KisNodeSP)));
+    connect(document->image().data(), SIGNAL(sigRemoveNodeAsync(KisNodeSP)), this, SLOT(slotNodeRemoved(KisNodeSP)));
+    connect(document, &KisDocument::sigReferenceImagesLayerChanged, this, &KisReferenceImagesDecoration::slotNodeAdded);
 
     auto referenceImageLayer = document->referenceImagesLayer();
     if (referenceImageLayer) {
-        setReferenceImageLayer(referenceImageLayer);
+        setReferenceImageLayer(referenceImageLayer, /* updateCanvas = */ viewReady);
     }
 }
 
@@ -125,6 +120,8 @@ bool KisReferenceImagesDecoration::documentHasReferenceImages() const
 
 void KisReferenceImagesDecoration::drawDecoration(QPainter &gc, const QRectF &/*updateRect*/, const KisCoordinatesConverter *converter, KisCanvas2 */*canvas*/)
 {
+    // TODO: can we use partial updates here?
+
     KisSharedPtr<KisReferenceImagesLayer> layer = d->layer.toStrongRef();
 
     if (!layer.isNull()) {
@@ -146,10 +143,21 @@ void KisReferenceImagesDecoration::drawDecoration(QPainter &gc, const QRectF &/*
 
 void KisReferenceImagesDecoration::slotNodeAdded(KisNodeSP node)
 {
-    auto *referenceImagesLayer = dynamic_cast<KisReferenceImagesLayer*>(node.data());
+    KisReferenceImagesLayer *referenceImagesLayer =
+        dynamic_cast<KisReferenceImagesLayer*>(node.data());
 
     if (referenceImagesLayer) {
-        setReferenceImageLayer(referenceImagesLayer);
+        setReferenceImageLayer(referenceImagesLayer, /* updateCanvas = */ true);
+    }
+}
+
+void KisReferenceImagesDecoration::slotNodeRemoved(KisNodeSP node)
+{
+    KisReferenceImagesLayer *referenceImagesLayer =
+        dynamic_cast<KisReferenceImagesLayer*>(node.data());
+
+    if (referenceImagesLayer && referenceImagesLayer == d->layer) {
+        setReferenceImageLayer(0, true);
     }
 }
 
@@ -161,11 +169,28 @@ void KisReferenceImagesDecoration::slotReferenceImagesChanged(const QRectF &dirt
     view()->canvasBase()->updateCanvas(documentRect);
 }
 
-void KisReferenceImagesDecoration::setReferenceImageLayer(KisSharedPtr<KisReferenceImagesLayer> layer)
+void KisReferenceImagesDecoration::setReferenceImageLayer(KisSharedPtr<KisReferenceImagesLayer> layer, bool updateCanvas)
 {
-    d->layer = layer;
-    connect(
-            layer.data(), SIGNAL(sigUpdateCanvas(const QRectF&)),
-            this, SLOT(slotReferenceImagesChanged(const QRectF&))
-    );
+    if (d->layer != layer.data()) {
+        KisSharedPtr<KisReferenceImagesLayer> oldLayer = d->layer.toStrongRef();
+        if (oldLayer) {
+            oldLayer->disconnect(this);
+        }
+
+        d->layer = layer;
+
+        if (layer) {
+            connect(layer.data(), SIGNAL(sigUpdateCanvas(QRectF)),
+                    this, SLOT(slotReferenceImagesChanged(QRectF)));
+
+            const QRectF dirtyRect = layer->boundingImageRect();
+
+            // If the view is not ready yet (because this is being constructed
+            // from view.d's ctor and thus view.d is not available now),
+            // do not update canvas because it will lead to a crash.
+            if (updateCanvas && !dirtyRect.isEmpty()) { // in case the reference layer is just being loaded from the .kra file
+                slotReferenceImagesChanged(dirtyRect);
+            }
+        }
+    }
 }
